pub struct FsFixture { /* private fields */ }Implementations
Sourceimpl FsFixture
impl FsFixture
Sourcepub fn path_join(&self, path: &str) -> PathBuf
pub fn path_join(&self, path: &str) -> PathBuf
Returns the path to a file in the fixture directory
Sourcepub fn write_file(&self, path: &str, content: &str) -> Result<()>
pub fn write_file(&self, path: &str, content: &str) -> Result<()>
Writes to a file in the fixture directory
Errors
This function will return an error if the file could not be written.
Sourcepub fn read_file(&self, path: &str) -> Result<String>
pub fn read_file(&self, path: &str) -> Result<String>
Reads a file from the fixture directory
Errors
This function will return an error if the file could not be read.