FsFixture

Struct FsFixture 

pub struct FsFixture { /* private fields */ }

Implementations

Source

impl FsFixture

pub fn path(&self) -> &Path

Returns the path to the fixture directory

pub fn path_join(&self, path: &str) -> PathBuf

Returns the path to a file in the fixture directory

pub fn exists(&self, path: &str) -> bool

Checks if a file exists in the fixture directory

pub fn write_file(&self, path: &str, content: &str) -> Result<()>

Writes to a file in the fixture directory

Errors

This function will return an error if the file could not be written.

pub fn read_file(&self, path: &str) -> Result<String>

Reads a file from the fixture directory

Errors

This function will return an error if the file could not be read.

pub fn remove_file(&self, path: &str) -> Result<()>

Removes a file from the fixture directory

Errors

This function will return an error if the file could not be removed.

pub fn remove(&self) -> Result<(), Error>

Removes the fixture directory and all of its files

Errors

This function will return an error if the fixture directory could not be removed.